'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var fs = require('fs-extra');
var yaml = require('js-yaml');
var zod = require('zod');
var k8sApply = require('k8s-apply');
var path = require('path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var yaml__namespace = /*#__PURE__*/_interopNamespace(yaml);
var path__default = /*#__PURE__*/_interopDefaultLegacy(path);

const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "deploy:kubernetes",
    description: "Deploys Kubernetes manifests.",
    schema: {
      input: zod.z.object({
        manifestDirectory: zod.z.string().describe("The directory containing Kubernetes manifests"),
        authToken: zod.z.string().describe("Authentication token to access the Kubernetes cluster"),
        clusterUrl: zod.z.string().describe("URL of the Kubernetes cluster")
      })
    },
    async handler(ctx) {
      const { manifestDirectory, authToken, clusterUrl } = ctx.input;
      try {
        const cwd = process.cwd();
        ctx.logger.info(`Current Working Directory: ${cwd}`);
        const files = await fs__default["default"].promises.readdir(manifestDirectory);
        ctx.logger.info(`Files in ${manifestDirectory}: ${files.join(", ")}`);
        const yamlFiles = await findAllYamlFiles(manifestDirectory);
        for (const filePath of yamlFiles) {
          let manifestYaml = "";
          let manifestObject;
          try {
            manifestYaml = await fs__default["default"].promises.readFile(filePath, {
              encoding: "utf-8"
            });
            manifestObject = yaml__namespace.load(manifestYaml);
          } catch (error) {
            ctx.logger.error(`Error processing file: ${filePath}`, error);
            continue;
          }
          try {
            const response = await k8sApply.applyObject(manifestObject, {
              server: clusterUrl,
              token: authToken
            });
            ctx.logger.info(
              `Deployment response for ${filePath}: ${JSON.stringify(response)}`
            );
          } catch (error) {
            ctx.logger.error(`Deployment failed for ${filePath}: ${error}`);
          }
        }
      } catch (error) {
        ctx.logger.error("An error occurred during deployment:", error);
        throw error;
      }
    }
  });
};
async function findAllYamlFiles(dir) {
  const dirents = await fs__default["default"].promises.readdir(dir, { withFileTypes: true });
  const files = await Promise.all(
    dirents.map((dirent) => {
      const res = path__default["default"].resolve(dir, dirent.name);
      return dirent.isDirectory() ? findAllYamlFiles(res) : res;
    })
  );
  return Array.prototype.concat(...files).filter((file) => file.endsWith(".yaml") || file.endsWith(".yml"));
}

exports.deployKubernetesAction = deployKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
